Module sqlx_exec

Module sqlx_exec 

Functions

exec
fetch_as_all
Build a sqlx::query_as for the D (Data) generic type, binds the values, and does a .fetch_all and returns Vec
fetch_as_one
Build a sqlx::query_as for the D (Data) generic type, binds the values, and does a .fetch_one and returns E
fetch_as_optional
Build a sqlx::query_as for the D (Data) generic type, binds the values, and does a .fetch_one and returns E