Functions
- exec
- fetch_
as_ all - Build a sqlx::query_as for the D (Data) generic type, binds the values, and does a .fetch_all and returns Vec
- fetch_
as_ one - Build a sqlx::query_as for the D (Data) generic type, binds the values, and does a .fetch_one and returns E
- fetch_
as_ optional - Build a sqlx::query_as for the D (Data) generic type, binds the values, and does a .fetch_one and returns E